ImageLoader (Android)
=====================

ImageLoader(Android) is an standalone library used to make the image downloading and cache easier.

The library makes use of a memory cache, which size can be configured at runtime, and a Disk cache,
to store images in the external storage of the device. This disk cache is based on the one provided
in the Ice Cream Sandwich source code.

Usage
=====

The simplest usage of this tool is to get ImageLoader instance, and just call the
`public void displayImage(String url, Activity activity, ImageView imageView)` method:

        // Get the singleton instance
        ImageLoader imageLoader = ImageLoader.getImageLoader(context);

        // Display image
        imageLoader.displayImage(imageUrl, activity, imageView);

There are 3 other ways in which you can call `displayImage`:

- With a target size:
        public void displayImage(String url, Activity activity, ImageView imageView, ImageSize size) {...}

Where size is an ImageSize (com.ichinaski.imageloader.ImageSize) instance. ImageSize determines the desired 
size of the final Bitmap, which will be sampled down to fit within the bounds set by this object. A null value
for this parameters will not re-scale the image (Thus it can take up more space in memory than necessary).

- Setting a custom cache parameter (activated by default):

        public void displayImage(String url, Activity activity, ImageView imageView, ImageSize size, boolean cache) {...}

Where cache(boolean) determines is this image should be cached after its download.

- With a custom Bitmap handler (the default one just displays the Bitmap in the ImageView):

            public void displayImage(String url, Activity activity, ImageView imageView, ImageSize size,
                    boolean cache, IImageLoaderCallback onLoadListener) {...}

Where onLoadListener (com.ichinaski.imageloader.IImageLoaderCallback) sets a custom callback to handle the Bitmap. This can be used,
for example to set a fade in animation in the moment that the Bitmap is get:

        IImageLoaderCallback imageListener = new IImageLoaderCallback() {
            @Override
            public void onImageLoaded(ImageView iv, Bitmap bmp, String url) {
                if (iv != null && bmp != null) {
                    iv.setImageBitmap(bmp);

                    // Load the animation
                    Animation myFadeInAnimation = AnimationUtils.loadAnimation(context, R.anim.fade_in);
                    iv.startAnimation(myFadeInAnimation);
                }
            }
        };

Custom the ImageLoader for your project:
- You can initialize the ImageLoader with custom parameters, JUST ONCE, AND ONLY BEFORE ANY CALL TO `getImageLoader(Context)`.
The best place to initialize the ImageLoader is on you Application's `onCreate()` method. If no initialization is made to the
ImageLoader, the default one will be applied. 

    *NOTE*: See ImageCacheParams and ImageLoaderConfig for a custom initialization.
