
package com.ichinaski.imageloadersamples;

import java.util.ArrayList;
import java.util.List;

import com.ichinaski.imageloader.ImageLoader;
import com.ichinaski.imageloader.ImageSize;

import android.app.Activity;
import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Display;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

public class AlbumListActivity extends ListActivity {
    private List<Album> albums;
    private AlbumAdapter adapter;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        albums = new ArrayList<AlbumListActivity.Album>();
        albums.add(new Album("Bob Dylan", "Highway 61 Revisited", "http://75rpm.com/ildemo/hw61.jpg"));
        albums.add(new Album("The Doors", "The Doors", "http://75rpm.com/ildemo/doors.jpg"));
        albums.add(new Album("The Beatles", "Revolver", "http://75rpm.com/ildemo/revolver.jpg"));
        albums.add(new Album("Jimi Hendrix", "Are You Experienced?", "http://75rpm.com/ildemo/areuexp.jpg"));
        albums.add(new Album("The Rolling Stones", "Exile on Main St.", "http://75rpm.com/ildemo/exile.jpg"));
        albums.add(new Album("Led Zeppelin", "IV", "http://75rpm.com/ildemo/iv.jpg"));
        albums.add(new Album("The Clash", "London Calling", "http://75rpm.com/ildemo/lcalling.jpg"));
        albums.add(new Album("Guns N' Roses", "Appetite for Destruction", "http://75rpm.com/ildemo/apetite.jpg"));
        albums.add(new Album("Radiohead", "OK Computer", "http://75rpm.com/ildemo/ok.jpg"));
        albums.add(new Album("Pearl Jam", "Ten", "http://75rpm.com/ildemo/ten.jpg"));
        
        adapter = new AlbumAdapter(this, albums);
        setListAdapter(adapter);
        getListView().setItemsCanFocus(true);
    }
    
    @Override
    public void onDestroy () {
        super.onDestroy();
        setListAdapter(null);
    }

    public static class AlbumAdapter extends ArrayAdapter<Album> {
        private static int layoutResource = R.layout.album_row;
        private ImageLoader imageLoader;
        private ImageSize coverSize;

        public AlbumAdapter(Context context, List<Album> albumList) {
            super(context, layoutResource, albumList);
            imageLoader = ImageLoader.getImageLoader(context);
            Display display = ((WindowManager)context.getSystemService(Context.WINDOW_SERVICE))
                    .getDefaultDisplay();
            
	        DisplayMetrics metrics = new DisplayMetrics();
	        display.getMetrics(metrics);
	
	        ImageSize screenSize = new ImageSize(metrics.widthPixels, metrics.heightPixels);
	        // Cover size -> limit its width to be 1/4 of the screen (at the most). If the original is smaller is not scaled down.
            coverSize = new ImageSize(screenSize.width / 4, 0);
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            ViewHolder holder;
            View view = convertView;
            if (view == null) {
                LayoutInflater vi = (LayoutInflater)getContext().getSystemService(
                        Context.LAYOUT_INFLATER_SERVICE);
                view = vi.inflate(layoutResource, null);
                holder = new ViewHolder();

                holder.artistView = (TextView)view.findViewById(R.id.artist);
                holder.titleView = (TextView)view.findViewById(R.id.title);
                holder.coverView = (ImageView)view.findViewById(R.id.cover);
                view.setTag(holder);
            } else {
                holder = (ViewHolder)view.getTag();
            }

            final Album album = getItem(position);

            // Artist & title
            holder.artistView.setText(album.artist);
            holder.titleView.setText(album.title);

            // Set loading image, in this case is a black vinyl.
            holder.coverView.setImageResource(R.drawable.vinyl_cover);
            imageLoader.displayImage(album.image, (Activity)getContext(), holder.coverView, coverSize);
            
            view.setOnClickListener(new OnClickListener() {
                
                @Override
                public void onClick(View v) {
                    Intent intent = new Intent(getContext(), CoverFullActivity.class);
                    Bundle extras = new Bundle();
                    extras.putString(CoverFullActivity.EXTRA_IMAGE, album.image);
                    intent.putExtras(extras);
                    getContext().startActivity(intent);
                }
            });

            return view;
        }
    }

    /**
     * Simple list row holder
     */
    public static class ViewHolder {
        TextView artistView, titleView;
        ImageView coverView;
    }
    
    /**
     * Album class, just to wrap the artist basic info and cover url
     */
    public static class Album {
        String artist, title, image;
        
        public Album (String artist, String title, String image) {
            this.artist = artist;
            this.title = title;
            this.image = image;
        }
    }

}
